const gulp = require('gulp');
const notify = require('gulp-notify');  // エラー通知
const plumber = require('gulp-plumber'); // エラー時のタスク停止防止
const debug = require('gulp-debug'); // ログ表示

const path = require('path');
const named = require('vinyl-named');
const filter = require('gulp-filter'); // ファイルフィルター

const webpack = require('webpack');
const webpackStream = require('webpack-stream');
const webpackConfig = require('./webpack.config.js');

const paths = {
  js: {
    src: 'src/assets/js/**/*.js', // コンパイル対象
    dest: 'public/assets/js' // 出力先
  }
}

/**
 * jsタスクを実行する関数
 */
function js() {
  return gulp.src(paths.js.src)
    .pipe(plumber({
      errorHandler: notify.onError('Error: <%= error.message %>')
    }))
    .pipe(filter(function (file) { // _から始まるファイルを除外
      return !/\/_/.test(file.path) && !/^_/.test(file.relative);
    }))
    .pipe(named((file) => {
        const p = path.parse(file.relative);
        return ((p.dir) ? p.dir + path.sep : '') + p.name;
      })
    )
    .pipe(webpackStream(webpackConfig, webpack))
    .pipe(gulp.dest(paths.js.dest))
    .pipe(debug({title: 'js dest:'}));
}

/**
 * watchタスクを実行する関数
 */
function watch() {
  return gulp.watch(paths.js.src, gulp.series(js))
}

exports.js = js; // jsタスク
exports.watch = watch; // watchタスク
exports.default = gulp.series(js); // defaultタスク
